@@ -3,7 +3,7 @@ BEGIN {
   $Yeb::Application::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Yeb::Application::VERSION = '0.011';
+  $Yeb::Application::VERSION = '0.012';
 }
 # ABSTRACT: Main Meta Class for a Yeb Application
 
@@ -19,6 +19,7 @@ use List::Util qw( reduce );
 use Hash::Merge qw( merge );
 use URL::Encode qw( url_encode_utf8 );
 use List::MoreUtils qw(any);
+use Sys::Hostname;
 
 use Carp;
 
@@ -135,6 +136,7 @@ has yeb_functions => (
 			cfg => sub { $self->config },
 			root => sub { path($self->root,@_) },
 			cur => sub { path($self->current_dir,@_) },
+			hostname => sub { hostname() },
 
 			cc => sub { $self->cc },
 			env => sub { $self->hash_accessor($self->cc->env,@_) },
@@ -354,7 +356,7 @@ Yeb::Application - Main Meta Class for a Yeb Application
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SUPPORT
 
